.. _release_history:

Release and Version History
==============================================================================


x.y.z (Backlog)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

**Minor Improvements**

**Bugfixes**

**Miscellaneous**


0.1.1 (2023-06-26)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- First release
- Add the following constant:
    - ``acore_constants.api.TagKey.SERVER_ID = "wserver:server_id"``
    - ``acore_constants.api.TagKey.WOW_STATUS_MEASURE_TIME_TAG_KEY = "wserver:wow_status_measure_time"``
    - ``acore_constants.api.TagKey.WOW_STATUS_TAG_KEY = "wserver:wow_status"``
